@@ -228,13 +228,14 @@ class TrayIcon (QtGui.QSystemTrayIcon):
         return menu
 
     def check_for_update(self):
-        if self._parent.localhost_ClientObj:
-            if UpdateInfo:
-                uinfo = UpdateInfo(self._parent.localhost_ClientObj.VarsApi)
-                return (uinfo.need_update() and
-                        not uinfo.update_already_run() and
-                        not self.get_update_pid() and
-                        not self.update_thread.isRunning())
+        if hasattr(self._parent, "localhost_ClientObj"):
+            if self._parent.localhost_ClientObj:
+                if UpdateInfo:
+                    uinfo = UpdateInfo(self._parent.localhost_ClientObj.VarsApi)
+                    return (uinfo.need_update() and
+                            not uinfo.update_already_run() and
+                            not self.get_update_pid() and
+                            not self.update_thread.isRunning())
         return False
 
     def set_icon(self, online, has_update=None):
